@@ -1,7 +1,9 @@
-use gdk4::prelude::ActionExt;
 use std::sync::Arc;
 use std::sync::Mutex;
 
+#[cfg(feature = "latest-gtk")]
+use gdk4::prelude::ActionExt;
+
 #[cfg(feature = "widgets")]
 use glib::ObjectExt;
 #[cfg(feature = "widgets")]
@@ -30,11 +32,27 @@ use crate::print_perf;
 #[derive(Debug, Clone)]
 pub struct Action {
     name: String,
+    #[cfg(feature = "latest-gtk")]
     argument: Option<glib::Variant>,
 }
 
 impl Action {
-    /// Create a new action
+    /// Create a new action.
+    ///
+    /// **NOTE:**
+    ///
+    /// **This is a placeholder since rustdoc server can not compile latest gtk yet
+    /// The actual signature looks like this:**
+    /// ```rust
+    /// fn new(name: String, argument: Option<glib::Variant>) -> Self
+    /// ```
+    #[cfg(not(feature = "latest-gtk"))]
+    fn new(name: String, argument: Option<String>) -> Self {
+        Action { name }
+    }
+
+    /// Create a new action.
+    #[cfg(feature = "latest-gtk")]
     fn new(name: String, argument: Option<glib::Variant>) -> Self {
         Action { name, argument }
     }
@@ -44,7 +62,22 @@ impl Action {
         &self.name
     }
 
+    /// Create a new action.
+    ///
+    /// **NOTE:**
+    ///
+    /// **This is a placeholder since rustdoc server can not compile latest gtk yet
+    /// The actual signature looks like this:**
+    /// ```rust
+    /// pub fn argument(&self) -> Option<&glib::Variant>
+    /// ```
+    #[cfg(not(feature = "latest-gtk"))]
+    pub fn argument(&self) -> Option<String> {
+        None
+    }
+
     /// Get the argument as glib::Variant.
+    #[cfg(feature = "latest-gtk")]
     pub fn argument(&self) -> Option<&glib::Variant> {
         self.argument.as_ref()
     }
@@ -52,6 +85,23 @@ impl Action {
     /// Try to get the argument as <T>. If either there is no argument
     /// or the argument is of a different type, the returned Option
     /// will be None.
+    ///
+    /// **NOTE:**
+    ///
+    /// **This is a placeholder since rustdoc server can not compile latest gtk yet
+    /// The actual signature looks like this:**
+    /// ```rust
+    /// pub fn arg<T: glib::FromVariant + Sized>(&self) -> Option<T>
+    /// ```
+    #[cfg(not(feature = "latest-gtk"))]
+    pub fn arg<T: Sized>(&self) -> Option<String> {
+        None
+    }
+
+    /// Try to get the argument as <T>. If either there is no argument
+    /// or the argument is of a different type, the returned Option
+    /// will be None.
+    #[cfg(feature = "latest-gtk")]
     pub fn arg<T: glib::FromVariant + Sized>(&self) -> Option<T> {
         if self.argument().is_some() {
             self.argument().unwrap().get()
@@ -366,7 +416,20 @@ impl<S: std::fmt::Debug + Clone + Default + PartialEq + Eq> Store<S> {
         )
     }
 
-    /// Dispatch the given arguments as an Action.
+    /// Dispatch the given arguments as an [Action](crate::Action).
+    ///
+    /// **NOTE:**
+    ///
+    /// **This is a placeholder since rustdoc server can not compile latest gtk yet
+    /// The actual signature looks like this:**
+    /// ```rust
+    /// pub fn dispatch(&self, action: String, argument: Option<glib::Variant>)
+    /// ```
+    #[cfg(not(feature = "glib"))]
+    pub fn dispatch(&self, action: String, argument: Option<String>) {}
+
+    /// Dispatch the given arguments as an [Action](crate::Action).
+    #[cfg(feature = "glib")]
     pub fn dispatch(&self, action: String, argument: Option<glib::Variant>) {
         let m = format!("Dispatch action {:?} with argument {:?}", action, argument);
         print_perf!(
@@ -449,6 +512,19 @@ impl<S: std::fmt::Debug + Clone + Default + PartialEq + Eq> Store<S> {
     }
 
     /// Delegate GTK actions as gstore::Actions to this store.
+    ///
+    /// **NOTE:**
+    ///
+    /// **This is a placeholder since rustdoc server can not compile latest gtk yet
+    /// The actual signature looks like this:**
+    /// ```rust
+    /// pub fn delegate(&'static self) -> glib::Sender<(gdk4::gio::SimpleAction, Option<glib::Variant>)>
+    /// ```
+    #[cfg(not(feature = "latest-gtk"))]
+    pub fn delegate(&'static self) {}
+
+    /// Delegate GTK actions as gstore::Actions to this store.
+    #[cfg(feature = "latest-gtk")]
     pub fn delegate(
         &'static self,
     ) -> glib::Sender<(gdk4::gio::SimpleAction, Option<glib::Variant>)> {
